@@ -12,4 +12,7 @@ def update_goscale_plugins():
 @task(name='goscale.tasks.update_goscale_plugin_posts')
 def update_goscale_plugin_posts(plugin_id):
     instance, count = utils.update_plugin(plugin_id)
-    print 'Updated %d posts for %s (%d)' % (count, instance, plugin_id)
+    if instance:
+        print 'Updated %d posts for %s (%d)' % (count, instance, plugin_id)
+    else:
+        print 'Couldn\'t update posts for plugin_id: %d' % plugin_id
\ No newline at end of file
